<?php
/*
Copyright (©) 2003-2013 Teus Benschop.

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
*/
?>
<p>
  <?php echo gettext ("Notes") ?>
  |
  <a href="select.php">[<?php echo gettext ("select") ?>]</a>
  <?php if ($this->level >= 5) { ?>
    |
    [<a href="bulk.php"><?php echo gettext ("update") ?></a>]
  <?php } ?>
  |
  <a href="create.php"><?php echo gettext ("Create note") ?></a>  
</p>
<br>
<div id="noteslist"><?php echo gettext ("Loading...") ?></div>
<script type="text/javascript" src="index.js"></script>
<script type="text/javascript" src="poll.js"></script>
